=====
Usage
=====

To use FConcrete in a project::

    import fconcrete as fc


.. toctree::
   :maxdepth: 3
   :caption: Use Examples:

   Beam usage examples <usages/Beam.rst>
   ConcreteBeam usage examples <usages/ConcreteBeam.rst>
   Analysis usage examples <usages/Analysis.rst>